@@ -1,8 +1,8 @@
 /// Single instruction of the interpreter
 #[derive(Debug, Clone, Copy, Eq, PartialEq, num_enum::TryFromPrimitive)]
-#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
+// #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 #[repr(u8)]
-pub enum Instruction {
+pub(crate) enum Instruction {
     /// Add two numbers
     Add,
     /// Subtract two numbers
@@ -80,4 +80,58 @@ pub enum Instruction {
     /// Pops an Object instance and a Value from the stack then sets the table value at the encoded
     /// key
     SetProperty,
+    /// Pushes the length of the topmost table to the stack
+    /// Errors if the top Value is not a Table
+    Len,
+
+    /// Must be called before the first call to Repeat in a loop
+    BeginRepeat,
+    Repeat,
+
+    BeginForEach,
+    ForEach,
+}
+
+/// return the number of bytes this instruction spans in the bytecode
+pub(crate) const fn instruction_span(instr: Instruction) -> i32 {
+    match instr {
+        Instruction::Add
+        | Instruction::Sub
+        | Instruction::Exit
+        | Instruction::Mul
+        | Instruction::Div
+        | Instruction::Call
+        | Instruction::Equals
+        | Instruction::NotEquals
+        | Instruction::Less
+        | Instruction::LessOrEq
+        | Instruction::Pop
+        | Instruction::Pass
+        | Instruction::ScalarNil
+        | Instruction::ClearStack
+        | Instruction::CopyLast
+        | Instruction::Return
+        | Instruction::SwapLast
+        | Instruction::And
+        | Instruction::Or
+        | Instruction::Xor
+        | Instruction::InitTable
+        | Instruction::Len
+        | Instruction::BeginRepeat
+        | Instruction::BeginForEach
+        | Instruction::Not => 1,
+        //
+        Instruction::ScalarInt | Instruction::ScalarFloat => 9,
+        Instruction::StringLiteral => 5,
+        //
+        Instruction::SetLocalVar
+        | Instruction::ReadLocalVar
+        | Instruction::SetProperty
+        | Instruction::GetProperty
+        | Instruction::SetGlobalVar
+        | Instruction::ReadGlobalVar => 5,
+        //
+        Instruction::Goto | Instruction::GotoIfTrue | Instruction::GotoIfFalse => 5,
+        Instruction::ForEach | Instruction::Repeat | Instruction::CallLane => 9,
+    }
 }
